PlayerM3u8Platform class abstract

Inheritance
  • Object
  • PlatformInterface
  • PlayerM3u8Platform
Implementers

Constructors

PlayerM3u8Platform()

Properties

cacheEvents Stream<M3u8CacheEvent>
no setter
events Stream<M3u8PlayerEvent>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cacheTasks() Future<List<M3u8CacheTask>>
cancelPrecache(String taskId) Future<void>
clearCache() Future<void>
clearSourceCache(M3u8Source source) Future<void>
configureCache({required int maxSizeBytes, int maxConcurrentPrecacheTasks = 2}) Future<void>
create({required M3u8Source source, M3u8RecoveryPolicy recoveryPolicy = M3u8RecoveryPolicy.defaults, Duration initialPosition = Duration.zero, double playbackSpeed = 1.0, double volume = 1.0, bool isMuted = false, List<M3u8SubtitleTrack> subtitles = const <M3u8SubtitleTrack>[], String? selectedSubtitleId, String? selectedAudioTrackId}) Future<int>
disposePlayer(int playerId) Future<void>
getCacheInfo() Future<M3u8CacheInfo>
getScreenBrightness() Future<double>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause(int playerId) Future<void>
pausePrecache(String taskId) Future<void>
play(int playerId) Future<void>
precache({required M3u8Source source, Duration initialPosition = Duration.zero, M3u8Quality quality = M3u8Quality.auto, int priority = 0, int maxRetries = 2, Map<String, Object?> metadata = const <String, Object?>{}}) Future<String>
resumePrecache(String taskId) Future<void>
seekTo(int playerId, Duration position) Future<void>
setAudioTrack(int playerId, String? audioTrackId) Future<void>
setMuted(int playerId, bool isMuted) Future<void>
setPlaybackSpeed(int playerId, double speed) Future<void>
setQuality(int playerId, M3u8Quality quality) Future<void>
setRecoveryPolicy(int playerId, M3u8RecoveryPolicy recoveryPolicy) Future<void>
setScreenBrightness(double brightness) Future<void>
setSubtitle(int playerId, String? subtitleId) Future<void>
setVolume(int playerId, double volume) Future<void>
sourceCacheInfo(M3u8Source source) Future<M3u8CacheInfo>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance PlayerM3u8Platform
getter/setter pair